Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1061)

Unified Diff: mandoline/ui/phone_ui/phone_browser_application_delegate.h

Issue 1340983002: Mandoline UI Process: Update namespaces and file names (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebased Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mandoline/ui/phone_ui/phone_browser_application_delegate.h
diff --git a/mandoline/ui/phone_ui/phone_browser_application_delegate.h b/mandoline/ui/phone_ui/phone_browser_application_delegate.h
index f489a977db89650f9d01e18ea3d25fe6e83ae987..20883eabd580e13e00da851b8aaa61456340ef62 100644
--- a/mandoline/ui/phone_ui/phone_browser_application_delegate.h
+++ b/mandoline/ui/phone_ui/phone_browser_application_delegate.h
@@ -18,19 +18,19 @@
#include "mojo/application/public/cpp/interface_factory.h"
#include "mojo/common/weak_binding_set.h"
-namespace mojo {
+namespace mus {
class View;
}
namespace mandoline {
-class PhoneBrowserApplicationDelegate :
- public mojo::ApplicationDelegate,
- public LaunchHandler,
- public mojo::ViewTreeDelegate,
- public mojo::ViewObserver,
- public web_view::mojom::WebViewClient,
- public mojo::InterfaceFactory<LaunchHandler> {
+class PhoneBrowserApplicationDelegate
+ : public mojo::ApplicationDelegate,
+ public LaunchHandler,
+ public mus::ViewTreeDelegate,
+ public mus::ViewObserver,
+ public web_view::mojom::WebViewClient,
+ public mojo::InterfaceFactory<LaunchHandler> {
public:
PhoneBrowserApplicationDelegate();
~PhoneBrowserApplicationDelegate() override;
@@ -44,12 +44,12 @@ class PhoneBrowserApplicationDelegate :
// Overridden from LaunchHandler:
void LaunchURL(const mojo::String& url) override;
- // Overridden from mojo::ViewTreeDelegate:
- void OnEmbed(mojo::View* root) override;
- void OnConnectionLost(mojo::ViewTreeConnection* connection) override;
+ // Overridden from mus::ViewTreeDelegate:
+ void OnEmbed(mus::View* root) override;
+ void OnConnectionLost(mus::ViewTreeConnection* connection) override;
- // Overridden from mojo::ViewObserver:
- void OnViewBoundsChanged(mojo::View* view,
+ // Overridden from mus::ViewObserver:
+ void OnViewBoundsChanged(mus::View* view,
const mojo::Rect& old_bounds,
const mojo::Rect& new_bounds) override;
@@ -67,8 +67,8 @@ class PhoneBrowserApplicationDelegate :
mojo::ApplicationImpl* app_;
mojo::ViewTreeHostPtr host_;
- mojo::View* root_;
- mojo::View* content_;
+ mus::View* root_;
+ mus::View* content_;
web_view::WebView web_view_;
mojo::String default_url_;
« no previous file with comments | « mandoline/ui/omnibox/omnibox_application.cc ('k') | mandoline/ui/phone_ui/phone_browser_application_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698